aboutsummaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
authorCraig Jennings <c@cjennings.net>2025-11-17 03:12:26 -0600
committerCraig Jennings <c@cjennings.net>2025-11-17 03:12:26 -0600
commit1ce75fdfb0a2473b650e330a6ff5239385c8736a (patch)
tree6b96d637fd622badb2fb3bf60de714f1063de794 /modules
parent322903f798149c9f12e9153ff6afeffe0b2436d6 (diff)
downloaddotemacs-1ce75fdfb0a2473b650e330a6ff5239385c8736a.tar.gz
dotemacs-1ce75fdfb0a2473b650e330a6ff5239385c8736a.zip
chore(calendar-sync): Change default interval to 60 minutes
Changed default sync interval from 15 minutes to 60 minutes (1 hour). Rationale: - Calendar events typically don't change that frequently - Reduces network requests and potential blocking events - Users can still manually sync or adjust interval as needed - More conservative default that balances freshness with performance
Diffstat (limited to 'modules')
-rw-r--r--modules/calendar-sync.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/modules/calendar-sync.el b/modules/calendar-sync.el
index 2eb9e450..07e74b3a 100644
--- a/modules/calendar-sync.el
+++ b/modules/calendar-sync.el
@@ -46,9 +46,9 @@
"Google Calendar private .ics URL.
Get this from Google Calendar Settings → Integrate calendar → Secret address in iCal format.")
-(defvar calendar-sync-interval-minutes 15
+(defvar calendar-sync-interval-minutes 60
"Sync interval in minutes.
-Default: 15 minutes.")
+Default: 60 minutes (1 hour).")
(defvar calendar-sync-file gcal-file
"Location of synced calendar file.
@@ -442,7 +442,7 @@ Syncs immediately, then every `calendar-sync-interval-minutes' minutes."
))
;; Start auto-sync if enabled and URL is configured
;; Syncs immediately then every calendar-sync-interval-minutes (default: 15 minutes)
(when (and calendar-sync-auto-start calendar-sync-ics-url)
(calendar-sync-start))
@@ -442,7 +442,7 @@ Syncs immediately, then every `calendar-sync-interval-minutes' minutes."
))
;; Start auto-sync if enabled and URL is configured
-;; Syncs immediately then every calendar-sync-interval-minutes (default: 15 minutes)
+;; Syncs immediately then every calendar-sync-interval-minutes (default: 60 minutes)
(when (and calendar-sync-auto-start calendar-sync-ics-url)
(calendar-sync-start))